@@ -16,11 +16,11 @@ CGI::Untaint::Facebook - Validate a URL is a valid Facebook URL or ID
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
@@ -65,6 +65,12 @@ sub is_valid {
 		return 0;
 	}
 
+	if($value =~ /([a-zA-Z0-9\-\/\.:]+)/) {
+		$value = $1;
+	} else {
+		return 0;
+	}
+
 	my $browser = LWP::UserAgent->new();
 	$browser->ssl_opts(verify_hostname => 1, SSL_ca_file => Mozilla::CA::SSL_ca_file());
 	$browser->agent('CGI::Untaint::Facebook');	# TODO: from class name
